@@ -1,6 +1,6 @@
 #' Create a grid of square-shaped windows
 #'
-#' @param x A RasterLayer/RasterStack/RasterBrick
+#' @param x A SpatRaster
 #' @param size Expressed in the numbers of cells, is a length of the side of a square-shaped block of cells. It defines the extent of a local pattern. If `size=NULL` calculations are perfomed for the whole area
 #' @param shift Defines the shift between adjacent squares of cells along with the N-S and W-E directions. It describes the density (resolution) of the output grid. The resolution of the output map will be reduced to the original resolution multiplied by the shift. If shift=size the input map will be divided into a grid of non-overlapping square windows. Each square window defines the extent of a local pattern. If shift < size - results in the grid of overlapping square windows.
 #'
@@ -8,22 +8,23 @@
 #' @export
 #'
 #' @examples
+#' library(terra)
+#' race_raster = rast(system.file("extdata/race_raster.tif", package = "raceland"))
 #' x = create_realizations(race_raster, 1)
 #' y = create_grid(x, size = 10)
 #' y
 create_grid = function(x, size, shift = NULL){
-  if (!(methods::is(x, "RasterLayer") || methods::is(x, "RasterStack") || methods::is(x, "RasterBrick"))){
-    stop("x needs to be either RasterLayer, RasterStack or RasterBrick", call. = FALSE)
-  }
+  is_raster_x = check_is_raster(x)
+  x = check_input(x, is_raster_x)
   if (is.null(shift)){
     shift = size
   }
-  bb = sf::st_bbox(raster::extent(x))
+  bb = sf::st_bbox(terra::ext(x))
   offset = bb[c("xmin", "ymax")]
 
-  cellsize = c((size * raster::res(x)[1]), (size * raster::res(x)[2]))
-  cellshift = c(((shift) * raster::res(x)[[1]]),
-                ((shift) * raster::res(x)[[2]]))
+  cellsize = c((size * terra::res(x)[1]), (size * terra::res(x)[2]))
+  cellshift = c(((shift) * terra::res(x)[[1]]),
+                ((shift) * terra::res(x)[[2]]))
 
   nx = ceiling(abs((bb[3] - offset[1]) / cellshift[1]))
   ny = ceiling(abs((bb[2] - offset[2]) / cellshift[2]))
@@ -42,12 +43,12 @@ create_grid = function(x, size, shift = NULL){
     }
   }
 
-  my_grid = sf::st_sf(geom = sf::st_sfc(ret, crs = sf::st_crs(x)))
+  my_grid = sf::st_sf(geom = sf::st_sfc(ret, crs = sf::st_crs(terra::crs(x))))
 
   # if (raster::nlayers(x) == 1){
   #   df_ids = create_motifels_ids(raster::as.matrix(x), size, shift)
   # } else {
-    df_ids = create_motifels_ids(raster::as.matrix(x[[1]]), size, shift)
+    df_ids = create_motifels_ids(terra::as.matrix(x[[1]], wide = TRUE), size, shift)
   # }
 
   my_grid = cbind(df_ids, my_grid)
