@@ -5,24 +5,23 @@
 #' @param variables A character vector with columns names from `v`.
 #' The values from these columns will be (1) rasterized and (2) recalculated to densities.
 #' Each column will be represented as an layer in the output RasterStack
-#' @param ... Additional arguments as for [fasterize::fasterize()]
+#' @param ... Additional arguments as for [terra::rasterize()]
 #'
-#' @return a RasterStack
+#' @return a SpatRaster
 #' @export
 #'
 #' @examples
 #' library(sf)
-#' library(raster)
+#' library(terra)
 #' plot(pop_vector)
 #' popdens_raster = zones_to_raster(pop_vector, resolution = 30,
 #'                                  variables = c("ASIAN", "BLACK", "HISPANIC", "OTHER", "WHITE"))
 #' plot(popdens_raster)
 zones_to_raster = function(v, resolution, variables, ...){
 
-
-  v_extent = raster::extent(v)
-  v_crs = sf::st_crs(v)$proj4string
-  template_raster = raster::raster(v_extent,
+  v_extent = terra::ext(v)
+  v_crs = sf::st_crs(v)$wkt
+  template_raster = terra::rast(v_extent,
                                    crs = v_crs,
                                    resolution = resolution)
 
@@ -30,14 +29,15 @@ zones_to_raster = function(v, resolution, variables, ...){
   #                                  resolution = resolution)
 
   v$id = seq_len(nrow(v))
-  r_id = fasterize::fasterize(v, template_raster, field = "id", ...)
+  # r_id = fasterize::fasterize(v, template_raster, field = "id", ...)
+  r_id = terra::rasterize(terra::vect(v), template_raster, field = "id", ...)
 
   out = if (requireNamespace("pbapply", quietly = TRUE)){
-    raster::stack(pbapply::pblapply(variables, zone_to_raster,
+    terra::rast(pbapply::pblapply(variables, zone_to_raster,
                                     v = v, resolution = resolution,
                                     id_raster = r_id, ...))
   } else {
-    raster::stack(lapply(variables, zone_to_raster,
+    terra::rast(lapply(variables, zone_to_raster,
                          v = v, resolution = resolution,
                          id_raster = r_id, ...))
   }
@@ -45,14 +45,14 @@ zones_to_raster = function(v, resolution, variables, ...){
 
 zone_to_raster = function(variable, v, resolution, id_raster, ...){
   # recalculate densities
-  freq_df = as.data.frame(raster::freq(id_raster))
+  freq_df = as.data.frame(terra::freq(id_raster))
   vals_df = sf::st_drop_geometry(v[c(variable, "id")])
   names(vals_df) = c("pop", "value")
   df = merge(freq_df, vals_df, by = "value", all.x = TRUE)
   df$density = df$pop / df$count
   # reclasiffy values by densities
   rc_mat = df[c("value", "density")]
-  r = raster::reclassify(id_raster, rc_mat)
+  r = terra::classify(id_raster, rc_mat)
   names(r) = variable
   r
 }
