@@ -1,7 +1,7 @@
 real_raster = create_realizations(race_raster, n = 2)
 
 test_that("create_realizations is stable", {
-  expect_s4_class(real_raster, "RasterStack")
+  expect_s4_class(real_raster, "SpatRaster")
   expect_equal(res(real_raster), res(race_raster))
-  expect_equal(nlayers(real_raster), 2)
+  expect_equal(nlyr(real_raster), 2)
 })
