@@ -9,7 +9,7 @@ load(system.file("results", "popdens_raster.rda", package = "raceland"))
 set.seed(22)
 real_raster2 = create_realizations(race_raster, n = 5)
 
-weig_raster2 = create_densities(real_raster, race_raster, window_size = 4)
+weig_raster2 = create_densities(real_raster2, race_raster, window_size = 4)
 
 metr_df2 = calculate_metrics(real_raster, weig_raster,
                             neighbourhood = 4, fun = "mean", size = 4)
@@ -20,8 +20,9 @@ popdens_raster2 = zones_to_raster(pop_vector, resolution = 30,
                                   variables = c("ASIAN", "BLACK", "HISPANIC", "OTHER", "WHITE"))
 
 # tests -------------------------------------------------------------------
-expect_equivalent(real_raster2, real_raster)
-expect_equivalent(weig_raster2, weig_raster)
+expect_equivalent(real_raster2[], rast(real_raster)[])
+names(weig_raster2) = names(rast(weig_raster))
+expect_equivalent(weig_raster2, rast(weig_raster))
 expect_equivalent(metr_df2, metr_df)
 expect_equivalent(grid_sf2, grid_sf)
-expect_equivalent(popdens_raster2, popdens_raster)
+expect_equivalent(popdens_raster2, rast(popdens_raster))
